"""The `kfp.compiler` module contains the compiler for compiling pipeline
definitions."""
# Copyright 2020 The Kubeflow Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__all__ = [
    'Compiler',
    'KubernetesManifestOptions',
]
from kfp.compiler.compiler import Compiler
from kfp.compiler.compiler_utils import KubernetesManifestOptions